@import "icon-classes/classes-day.less";
@import "icon-classes/classes-night.less";
@import "icon-classes/classes-neutral.less";
@import "icon-classes/classes-misc.less";
@import "icon-classes/classes-moon.less";
@import "icon-classes/classes-moon-aliases.less";
@import "icon-classes/classes-time.less";
@import "icon-classes/classes-direction.less";
@import "icon-classes/classes-beaufort.less";
