{% load i18n %}

<div class="app-translation-footer text-muted">
    <p>
        {% translate "Do you want to help translate this app into your language or improve the existing translation?" %}
        -
        <a href="https://weblate.ppfeufer.de/engage/alliance-auth-apps/" target="_blank" rel="noopener noreferer">
            {% translate "Join our team of translators!" %}
        </a>
    </p>
</div>
